==> org.eclipse.emf.eef.mapping.edit.source_1.1.1.201206051542.jar: org/eclipse/emf/eef/mapping/filters/providers/FiltersMessages.java <==
/*******************************************************************************
 * Copyright (c) 2008, 2012 Obeo.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Obeo - initial API and implementation
 *******************************************************************************/
package org.eclipse.emf.eef.mapping.filters.providers;

import org.eclipse.osgi.util.NLS;

/**
 * @author <a href="mailto:nathalie.lepine@obeo.fr">Nathalie Lepine</a>
 * 
 */
public class FiltersMessages extends NLS {
	
	private static final String BUNDLE_NAME = "org.eclipse.emf.eef.mapping.filters.providers.filtersMessages"; //$NON-NLS-1$

	
	public static String OnlyReferenceTypeFilterPropertiesEditionPart_ReferencedFeatureGroupLabel;

	
	public static String OCLFilterPropertiesEditionPart_FilterExpressionGroupLabel;

	
	public static String JavaExpressionFilterPropertiesEditionPart_FilterExpressionGroupLabel;

	
	public static String JavaDeclarationFilterPropertiesEditionPart_FilterExpressionGroupLabel;

	
	public static String StrictTypingFilterPropertiesEditionPart_TypeGroupLabel;


	
	public static String OnlyReferenceTypeFilter_ReadOnly;

	
	public static String OnlyReferenceTypeFilter_Part_Title;

	
	public static String OCLFilter_ReadOnly;

	
	public static String OCLFilter_Part_Title;

	
	public static String JavaExpressionFilter_ReadOnly;

	
	public static String JavaExpressionFilter_Part_Title;

	
	public static String JavaDeclarationFilter_ReadOnly;

	
	public static String JavaDeclarationFilter_Part_Title;

	
	public static String StrictTypingFilter_ReadOnly;

	
	public static String StrictTypingFilter_Part_Title;


	
	public static String OnlyReferenceTypeFilterPropertiesEditionPart_ReferencedFeatureLabel;

	
	public static String OCLFilterPropertiesEditionPart_OCLExpressionBodyLabel;

	
	public static String JavaExpressionFilterPropertiesEditionPart_JavaExpressionBodyLabel;

	
	public static String JavaDeclarationFilterPropertiesEditionPart_MethodNameLabel;

	
	public static String StrictTypingFilterPropertiesEditionPart_RestrictionLabel;


	
	public static String PropertiesEditionPart_DocumentationLabel;

	
	public static String PropertiesEditionPart_IntegerValueMessage;

	
	public static String PropertiesEditionPart_FloatValueMessage;

	
	public static String PropertiesEditionPart_ShortValueMessage;

	
	public static String PropertiesEditionPart_LongValueMessage;

	
	public static String PropertiesEditionPart_ByteValueMessage;

	
	public static String PropertiesEditionPart_BigIntegerValueMessage;

	
	public static String PropertiesEditionPart_BigDecimalValueMessage;

	
	public static String PropertiesEditionPart_DoubleValueMessage;

	
	public static String PropertiesEditionPart_PropertiesGroupLabel;

	
	public static String PropertiesEditionPart_RequiredFeatureMessage;

	
	public static String PropertiesEditionPart_AddTableViewerLabel;

	
	public static String PropertiesEditionPart_EditTableViewerLabel;

	
	public static String PropertiesEditionPart_RemoveTableViewerLabel;

	
	public static String PropertiesEditionPart_AddListViewerLabel;

	
	public static String PropertiesEditionPart_RemoveListViewerLabel;

	// Start of user code for additionnal NLS Constants
	
	// End of user code

	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, FiltersMessages.class);
	}

	
	private FiltersMessages() {
		//protect instanciation
	}
}

==> org.eclipse.emf.eef.mapping.edit.source_1.5.1.201601141612.jar: org/eclipse/emf/eef/mapping/filters/providers/FiltersMessages.java <==
/*******************************************************************************
 * Copyright (c) 2008, 2012 Obeo.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Obeo - initial API and implementation
 *******************************************************************************/
package org.eclipse.emf.eef.mapping.filters.providers;

import org.eclipse.osgi.util.NLS;

/**
 * @author <a href="mailto:nathalie.lepine@obeo.fr">Nathalie Lepine</a>
 * 
 */
public class FiltersMessages extends NLS {
	
	private static final String BUNDLE_NAME = "org.eclipse.emf.eef.mapping.filters.providers.filtersMessages"; //$NON-NLS-1$

	
	public static String OnlyReferenceTypeFilterPropertiesEditionPart_ReferencedFeatureGroupLabel;

	
	public static String OCLFilterPropertiesEditionPart_FilterExpressionGroupLabel;

	
	public static String JavaExpressionFilterPropertiesEditionPart_FilterExpressionGroupLabel;

	
	public static String JavaDeclarationFilterPropertiesEditionPart_FilterExpressionGroupLabel;

	
	public static String StrictTypingFilterPropertiesEditionPart_TypeGroupLabel;

	
	public static String JavaDeclarationStepFilterPropertiesEditionPart_PropertiesGroupLabel;

	
	public static String JavaBodyStepFilterPropertiesEditionPart_PropertiesGroupLabel;


	
	public static String OnlyReferenceTypeFilter_ReadOnly;

	
	public static String OnlyReferenceTypeFilter_Part_Title;

	
	public static String OCLFilter_ReadOnly;

	
	public static String OCLFilter_Part_Title;

	
	public static String JavaExpressionFilter_ReadOnly;

	
	public static String JavaExpressionFilter_Part_Title;

	
	public static String JavaDeclarationFilter_ReadOnly;

	
	public static String JavaDeclarationFilter_Part_Title;

	
	public static String StrictTypingFilter_ReadOnly;

	
	public static String StrictTypingFilter_Part_Title;

	
	public static String JavaDeclarationStepFilter_ReadOnly;

	
	public static String JavaDeclarationStepFilter_Part_Title;

	
	public static String JavaBodyStepFilter_ReadOnly;

	
	public static String JavaBodyStepFilter_Part_Title;


	
	public static String OnlyReferenceTypeFilterPropertiesEditionPart_ReferencedFeatureLabel;

	
	public static String OCLFilterPropertiesEditionPart_OCLExpressionBodyLabel;

	
	public static String JavaExpressionFilterPropertiesEditionPart_JavaExpressionBodyLabel;

	
	public static String JavaDeclarationFilterPropertiesEditionPart_MethodNameLabel;

	
	public static String StrictTypingFilterPropertiesEditionPart_RestrictionLabel;

	
	public static String JavaDeclarationStepFilterPropertiesEditionPart_QualifiedClassLabel;

	
	public static String JavaDeclarationStepFilterPropertiesEditionPart_MethodFilterLabel;

	
	public static String JavaDeclarationStepFilterPropertiesEditionPart_StaticMethodLabel;

	
	public static String JavaBodyStepFilterPropertiesEditionPart_BodyLabel;


	
	public static String PropertiesEditionPart_DocumentationLabel;

	
	public static String PropertiesEditionPart_IntegerValueMessage;

	
	public static String PropertiesEditionPart_FloatValueMessage;

	
	public static String PropertiesEditionPart_ShortValueMessage;

	
	public static String PropertiesEditionPart_LongValueMessage;

	
	public static String PropertiesEditionPart_ByteValueMessage;

	
	public static String PropertiesEditionPart_BigIntegerValueMessage;

	
	public static String PropertiesEditionPart_BigDecimalValueMessage;

	
	public static String PropertiesEditionPart_DoubleValueMessage;

	
	public static String PropertiesEditionPart_PropertiesGroupLabel;

	
	public static String PropertiesEditionPart_RequiredFeatureMessage;

	
	public static String PropertiesEditionPart_AddTableViewerLabel;

	
	public static String PropertiesEditionPart_EditTableViewerLabel;

	
	public static String PropertiesEditionPart_RemoveTableViewerLabel;

	
	public static String PropertiesEditionPart_AddListViewerLabel;

	
	public static String PropertiesEditionPart_RemoveListViewerLabel;

	// Start of user code for additionnal NLS Constants
	
	// End of user code

	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, FiltersMessages.class);
	}

	
	private FiltersMessages() {
		//protect instanciation
	}
}
